<a href="https://www.islas.org.mx/"><img src="https://www.islas.org.mx/img/logo.svg" align="right" width="256" /></a>
# Population trend

Este repo lo usamos en lambdas y cormorant.

Tiene la clase para graficas `Plotter_Population_Trend_Model`.
